<?php namespace EscapeWork\Manager\Calendars\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\Calendars\Repositories\Calendar\CalendarRepository;
use EscapeWork\Manager\Calendars\Repositories\CalendarDay\CalendarDayRepository;
use View;
use Input;
use Redirect;
use Response;
use Request;
use Config;
use Msg;

class CalendarsController extends ManagerController
{

    public function __construct(CalendarRepository $calendar, CalendarDayRepository $calendarDay)
    {
        $this->calendar    = $calendar;
        $this->calendarDay = $calendarDay;

        $this->enableDefaultFilters('calendars');
    }

    public function index()
    {
        $view = View::make(Config::get('manager-calendars::views.calendars.index'));
        $view->calendars = $this->calendar->filterAndPaginate(Input::all());

        return $view;
    }

    public function create()
    {
        $this->calendar->fill(Input::old());

        $view              = View::make(Config::get('manager-calendars::views.calendars.form'));
        $view->calendar    = $this->calendar;
        $view->calendarDay = $this->calendarDay;
        $view->edit        = false;

        return $view;
    }

    public function store()
    {
        $this->calendar->fill(Input::except('date'));

        if (! $this->calendar->validate()) {
            return Redirect::route('manager.calendarios.create')
                        ->withInput()
                        ->withErrors($this->calendar->getValidationErrors());
        }

        $this->calendar->save();
        $this->calendarDay->calendar_id = $this->calendar->id;
        $this->calendarDay->insertFromArray(Input::get('date'));

        return Redirect::route('manager.calendarios.index')->with('message', 'O evento <strong>' . $this->calendar->title . '</strong> foi inserido com sucesso!');
    }

    public function edit($id)
    {
        $this->calendar = $this->calendar->findOrFail($id);

        Msg::setInfo('Editando o evento <strong>' . $this->calendar->title . '</strong>');

        $view           = View::make(Config::get('manager-calendars::views.calendars.form'));
        $view->calendar = $this->calendar;
        $view->edit     = true;

        return $view;
    }

    /**
     * Salvando no banco de dados
     */
    public function update($id)
    {
        $this->calendar = $this->calendar->findOrFail($id);
        $this->calendar->fill(Input::all());

        if ( $this->calendar->validate() === false) {
            return Redirect::route('manager.calendarios.edit', array($this->calendar->id))
                    ->withInput()
                    ->withErrors($this->calendar->getValidationErrors());
        }

        $this->calendar->save();

        # salvando as datas
        $this->calendarDay->calendar_id = $this->calendar->id;
        $this->calendarDay->deleteAllFromEdition();
        $this->calendarDay->insertFromArray(Input::get('date'));

        return Redirect::route('manager.calendarios.index')
                ->with('message', 'A edição <strong>'.$this->calendar->title.'</strong> foi editada com sucesso!');
    }

    public function destroy($id)
    {
        $this->calendar = $this->calendar->findOrFail($id);
        $this->calendar->delete();

        return Redirect::route('manager.calendarios.index')
                ->with('message', 'O evento <strong>'.$this->calendar->title.'</strong> foi excluído com sucesso!');
    }

    public function updateActive($id)
    {
        if (! $this->calendar = $this->calendar->find($id)) {
            return Response::json(array(
                'error' => 'Evento não encontrada'
            ));
        }

        $this->calendar->active = Input::get('active');
        $this->calendar->save();

        return Response::json(array(
            'message' => 'O evento foi atualizado com sucesso'
        ));
    }

    public function updateFeatured($id)
    {
        if (! $this->calendar = $this->calendar->find($id)) {
            return Response::json(array(
                'error' => 'Evento não encontrado'
            ));
        }

        $this->calendar->featured = Input::get('featured');
        $this->calendar->save();

        return Response::json(array(
            'message' => 'O evento foi atualizado com sucesso'
        ));
    }
}
