<?php namespace EscapeWork\Manager\Calendars\Providers;

use EscapeWork\Manager\Calendars\Commands\ConfigureCommand;
use Illuminate\Support\ServiceProvider;

class ManagerCalendarsServiceProvider extends ServiceProvider
{

    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        $this->package('escapework/manager-calendars', 'manager-calendars', realpath(__DIR__ . '/../../../../'));

        include_once(__DIR__ . '/../../../../routes.php');
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->registerCommands();
        $this->bindRepositories();
    }

    protected function bindRepositories()
    {
        $this->app->bind('EscapeWork\Manager\Calendars\Repositories\Calendar\CalendarRepository', 'EscapeWork\Manager\Calendars\Repositories\Calendar\EloquentCalendarRepository');
        $this->app->bind('EscapeWork\Manager\Calendars\Repositories\CalendarDay\CalendarDayRepository', 'EscapeWork\Manager\Calendars\Repositories\CalendarDay\EloquentCalendarDayRepository');
    }

    protected function registerCommands()
    {
        $this->app['command.manager.calendars.configure'] = $this->app->share(function($app)
        {
            return new ConfigureCommand;
        });

        $this->commands('command.manager.calendars.configure');
    }

    public function provides()
    {
        return array('command.manager.calendars.configure');
    }
}
