@extends('manager::layouts.master')

@section('content')
    <ul class="breadcrumb">
        <li><a href="{{ route('manager.home') }}">Home</a> <span class="divider">/</span></li>
        <li><a href="{{ route('manager.calendarios.index') }}">Calendário</a> <span class="divider">/</span></li>
        <li class="active">{{ $edit ? 'Editar' : 'Inserir' }}</li>
    </ul><!-- .breadcrumb -->

    <div class="page-header">
        <div class="pull-left">
            <h2>Calendário</h2>
        </div><!-- .pull-left -->

        <div class="pull-right">
            <a href="{{ route('manager.calendarios.index') }}" class="btn">Voltar</a>
        </div><!-- .pull-right -->

        <div class="clearfix"></div>
    </div><!-- .page-header -->

    {{ Msg::getAll() }}

    <form action="{{ ! $edit ? route('manager.calendarios.store') : route('manager.calendarios.update', $calendar->id) }}" method="post" id="form-calendar" class="form-horizontal">
        @if ($edit)
            <input type="hidden" name="_method" value="put" />
        @endif

        <fieldset>
            @section('fields')
                <div class="control-group">
                    <label for="title" class="control-label">Título</label>

                    <div class="controls">
                        <input type="text" name="title" id="title" class="input-xxlarge" value="{{ $calendar->title }}" required autofocus />
                    </div><!-- .controls -->
                </div><!-- .control-group -->

                <div class="control-group">
                    <label for="place" class="control-label">Local</label>

                    <div class="controls">
                        <input type="text" name="place" id="place" class="input-xxlarge" value="{{ $calendar->place }}" required />
                    </div><!-- .controls -->
                </div><!-- .control-group -->

                <div class="control-group">
                    <label for="description" class="control-label">Descrição</label>

                    <div class="controls">
                        <textarea  name="description" id="description" data-editor>{{ $calendar->description }}</textarea>
                    </div><!-- .controls -->
                </div><!-- .control-group -->

                <div class="controls controls-row">
                    @if (! $edit)
                        <div class="input-append">
                            <input type="text" name="date[]" class="span2" placeholder="dd/mm/aaaa" data-date data-calendar maxlength="10" required />
                            <a href="#" class="btn js-delete-date" title="Excluir data"><i class="icon-trash"></i></a>
                        </div><!-- .input-append -->
                    @else
                        @foreach ($calendar->days as $calendarDay)
                            <div class="input-append">
                                <input type="text" name="date[]" value="{{ date('d/m/Y', strtotime($calendarDay->day)) }}" class="span2" placeholder="dd/mm/aaaa" data-date data-calendar maxlength="10" required />
                                <a href="#" class="btn js-delete-date" title="Excluir data"><i class="icon-trash"></i></a>
                            </div><!-- .input-append -->
                        @endforeach
                    @endif

                    <a href="#" class="btn btn-small btn-primary js-add-date" title="Adicionar data" data-name="date[]"><i class="icon-plus icon-white"></i></a>
                </div><!-- .control-group -->
            @show
        </fieldset>

        <div class="form-actions">
            <input type="submit" class="btn btn-primary" value="Salvar">
            <a href="{{ route('manager.calendarios.index') }}" class="btn">Cancelar</a>
        </div><!-- .form-actions -->
    </form>
@stop

@section('scripts')
    @parent

    <script type="text/template" id="template-date">
        <div class="input-append">
            <input type="text" name="##name##" class="span2" placeholder="dd/mm/aaaa" data-date data-calendar maxlength="10" />
            <a href="#" class="btn js-delete-date" title="Excluir data"><i class="icon-trash"></i></a>
        </div><!-- .input-append -->
    </script>

    <script type="text/javascript">
        (function() {
            window.App = window.App || {};

            App.Manager = App.Manager || {};

            App.Manager.ProductEditions = {
                templates: {
                    date: $('#template-date')
                },

                wrapper: {
                    datepicker: '[data-calendar]'
                },

                init: function() {
                    this.fetchElements();
                    this.setMasks();

                    return this.listenEvents();
                },

                fetchElements: function() {
                    this.$btnAddDate = $('.js-add-date');
                    return this.$btnDeleteDate = $('.js-delete-date');
                },

                setMasks: function() {
                    $('[data-date]').mask('99/99/9999');
                    return this.initDatepicker();
                },

                initDatepicker: function(config) {
                    var _this;

                    _this = this;
                    return $(this.wrapper.datepicker).datepicker({

                        onSelect: function(date) {
                            _this.defaultDate = date;
                            return $(_this.wrapper.datepicker).datepicker('option', 'defaultDate', date);
                        },

                        defaultDate: _this.defaultDate
                    });
                },

                listenEvents: function() {
                    var _this;

                    _this = this;
                    this.$btnAddDate.on('click', function(e) {
                        e.preventDefault();
                        return _this.onAddDate($(this));
                    });
                    return this.listenDeleteDateEvent();
                },

                listenDeleteDateEvent: function() {
                    var _this;

                    _this = this;

                    return this.$btnDeleteDate.on('click', function(e) {
                        e.preventDefault();
                        return _this.onDeleteDate($(this));
                    });
                },

                onAddDate: function($btn) {
                    var date, name;

                    name = $btn.data('name');
                    date = this.templates.date.html().replace(/##name##/ig, name);
                    $btn.before(date);
                    this.fetchElements();
                    this.listenDeleteDateEvent();
                    return this.setMasks();
                },

                onDeleteDate: function($btn) {
                    return $btn.parent().remove();
                }
            };
            App.Manager.ProductEditions.init();
        }).call(this);
    </script>
@stop
