@extends('manager::layouts.master')

@section('content')
    <ul class="breadcrumb">
        <li><a href="{{ route('manager.home') }}">Home</a> <span class="divider">/</span></li>
        <li class="active">Calendário</li>
    </ul><!-- .breadcrumb -->

    <div class="page-header">
        <div class="pull-left">
            <h2>Calendário</h2>
        </div><!-- .pull-left -->

        <div class="pull-right">
            @if (Check::can('calendars', 'create'))
                <a href="{{ route('manager.calendarios.create') }}" class="btn btn-primary">Inserir novo evento</a>
            @endif
        </div><!-- .pull-right -->

        <div class="clearfix"></div>
    </div><!-- .page=header -->

    {{ Msg::getAll() }}

    @if (Check::can('calendars', 'read'))
        <form action="{{ route('manager.calendarios.index') }}" class="well form-inline" method="get" id="form-search">
            @section('search')
                <div class="pull-left">
                    <label>
                        <input type="text" name="title" placeholder="Título..." value="{{ Input::get('title') }}" maxlength="100" />
                    </label>&nbsp;
                </div>

                <div class="pull-left">
                    <button type="submit" class="btn btn-primary"><i class="icon-search icon-white"></i> Buscar</button>

                    <a class="btn btn-primary" href="{{ route('manager.calendarios.index') }}">
                        Limpar filtros
                    </a>
                </div>

                <div class="clearfix"></div>
            @show
        </form>

        <table class="table table-bordered table-striped table-hover">
            <thead>
                <tr>
                    <th>#</th>
                    <th><a href="{{ route('manager.calendarios.index', array('orderBy' => order_by('title'))) }}" title="Ordenar pelo título">Título</a></th>
                    <th><a href="{{ route('manager.calendarios.index', array('orderBy' => order_by('place'))) }}" title="Ordernar pelo local">Local</a></th>
                    <th>Destaque</th>
                    <th>Ativo</th>
                    <th>Ação</th>
                </tr>
            </thead>
            <tbody>
                @foreach ($calendars as $calendar)
                    <tr>
                        <td>{{ $calendar->id }}</td>
                        <td>{{ $calendar->title }}</td>
                        <td>{{ $calendar->place }}</td>
                        <td><input type="checkbox" value="1" data-id="{{ $calendar->id }}" class="js-update-featured" {{ $calendar->featured ? 'checked="checked"' : null }} /></td>
                        <td><input type="checkbox" value="1" data-id="{{ $calendar->id }}" class="js-update-active" {{ $calendar->active ? 'checked="checked"' : null }} /></td>
                        <td>
                            <div class="btn-group">
                                @if (Check::can('calendars', 'update'))
                                    <a href="{{ route('manager.calendarios.edit', $calendar->id) }}" class="btn btn-small" title="Editar">
                                        <i class="icon-pencil"></i> editar
                                    </a>
                                @endif

                                @if (Check::can('calendars', 'destroy'))
                                    <a href="{{ route('manager.calendarios.destroy', $calendar->id) }}" class="btn btn-small" data-delete="true" title="Excluir">
                                        <i class="icon-trash"></i> excluir
                                    </a>
                                @endif
                            </div><!-- .btn-group -->
                        </td>
                    </tr>
                @endforeach
            </tbody>
        </table><!-- .table -->

        {{ $calendars->links() }}
    @endif
@stop

@section('scripts')
    @parent

    <script type="text/javascript">
    (function() {
        window.App = window.App || {};

        App.Manager = App.Manager || {};

        App.Manager.Calendars = {
            init: function() {
                this.listenEventsActive();
                this.listenEventsFeature();
            },

            listenEventsActive: function() {
                var _this = this;

                $('.js-update-active').on('change', function(e) {
                    _this.updateActive($(this));
                });
            },

            updateActive: function($calendars) {
                var _this  = this,
                    id     = $calendars.data('id'),
                    active = $calendars.prop('checked') ? 1 : 0;

                $calendars.prop('disabled', true)

                $.post('/manager/calendarios/'+id+'/active', {
                    _method: 'put',
                    active: active
                }, function(result) {
                    $calendars.prop('disabled', false)
                });
            },

            listenEventsFeature: function() {
                var _this = this;

                $('.js-update-featured').on('change', function(e) {
                    _this.updateFeatured($(this));
                });
            },

            updateFeatured: function($calendars) {
                var _this  = this,
                    id     = $calendars.data('id'),
                    featured = $calendars.prop('checked') ? 1 : 0;

                $calendars.prop('disabled', true)

                $.post('/manager/calendarios/'+id+'/featured', {
                    _method: 'put',
                    featured: featured
                }, function(result) {
                    $calendars.prop('disabled', false)
                });
            },
        }

        App.Manager.Calendars.init();
    })();
    </script>
@stop
